UrlBuilder class
A utility class for building various types of URIs.
This class provides static methods to construct URIs for common actions like launching websites, making phone calls, sending emails/SMS, and interacting with social media applications. It also supports building URIs for map searches and calendar events.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
buildCalendarUri(
CalendarEvent? event) → Uri - Builds a Google Calendar event URI.
-
buildMapUri(
String? query, {Map< String, dynamic> ? queryParameters}) → Uri - Builds a URI for launching a map application or web map.
-
buildThreadsUri(
String? username) → Uri - Builds a URI for Threads.
-
buildUri(
{required LaunchType type, String? value, Map< String, dynamic> ? queryParameters, CalendarEvent? calendarEvent}) → Uri -
Builds a Uri based on the specified
typeand input parameters. -
buildXUri(
String? usernameOrId) → Uri - Builds a URI for X (Twitter).
-
isWebUrl(
String? url) → bool - Checks if a string is a valid web URL.