LaunchPreviewStyle class
Styling configuration for LaunchPreviewCard.
Constructors
- LaunchPreviewStyle({double height = 150, double imageHeight = 180, double borderRadius = 12, double elevation = 2, Color backgroundColor = Colors.white, TextStyle titleTextStyle = const TextStyle(fontSize: 16, fontWeight: FontWeight.bold), TextStyle descriptionTextStyle = const TextStyle(fontSize: 14, color: Colors.grey)})
-
Creates a LaunchPreviewStyle.
const
Properties
- backgroundColor → Color
-
The background color of the card.
final
- borderRadius → double
-
The border radius of the card.
final
- descriptionTextStyle → TextStyle
-
The style for the description text.
final
- elevation → double
-
The elevation of the card.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of the card.
final
- imageHeight → double
-
The height of the image section.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- titleTextStyle → TextStyle
-
The style for the title text.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultStyle(
BuildContext context) → LaunchPreviewStyle - The default style for LaunchPreviewCard using the current theme.